{{- /*
commonlib.s3.provisioning will create buckets based on the input.
usage:
  {{- include "commonlib.s3.provisioning" . -}}

example config will be:

xyz: -> your chart name here if put in the top level chart values.yaml
  minio:
    # required
    buckets:
      bucketKey:
        name: bucket-name
        # optional, defaults to false
        # purge bucket if it exists
        purge: true
    provisioning:
      ## required
      enabled: true

      ## override image used for provisioning
      ## optional
      # image:
      #   registry: harbor.nsbu.eng.vmware.com/nsx_intelligence_ob/clustering
      #   repository: blob
      #   tag: "v0.1"

      ## optional
      # backoffLimit: 10

      ## optinal
      # activeDeadlineSeconds: 60

      ## optional
      # restartPolicy: OnFailure

      ## optional
      jobName: "xyz-s3-provisioning"

      ## by default minio-client: "true" is added, add additional podLabels here
      # podLabels:
      #   kafka-client: "true"

      ## optional, add additional labels here
      # labels:
      #   security.vmware.com/keep: "true"

*/}}
{{- define "commonlib.s3.provisioning" -}}
{{- if .Values.minio.provisioning.enabled }}
apiVersion: batch/v1
kind: Job
metadata:
  name: {{ .Values.minio.provisioning.jobName | default (printf "%s-s3-provisioning" (default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-")) }}
  labels:
    # default labels
    helm.sh/chart: {{ printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
    app.kubernetes.io/name: {{ default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
    app.kubernetes.io/component: {{ default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
    app.kubernetes.io/instance: {{ .Release.Name }}
    {{- if .Chart.AppVersion }}
    app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
    {{- end }}
    app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- with .Values.minio.provisioning.labels }}
{{ toYaml . | indent 4 }}
{{- end }}
spec:
  completions: 1
  parallelism: 1
  {{- if .Values.minio.provisioning.backoffLimit }}
  backoffLimit: {{ .Values.minio.provisioning.backoffLimit }}
  {{- end }}
  template:
    metadata:
      labels:
        {{- with .Values.minio.provisioning.podLabels }}
        {{ toYaml . | indent 8 }}
        {{- end }}
        # selector labels
        app.kubernetes.io/name: {{ default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
        app.kubernetes.io/component: {{ default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
        app.kubernetes.io/instance: {{ .Release.Name }}
        # network policy labels
        allow-traffic-to-dns: "true"
        allow-traffic-to-kubeapi: "true"
        minio-client: "true"
    spec:
      {{- if .Values.minio.provisioning.activeDeadlineSeconds }}
      activeDeadlineSeconds: {{ .Values.minio.provisioning.activeDeadlineSeconds }}
      {{- end }}
      serviceAccountName: {{ .Values.minio.provisioning.serviceAccount.name }}
      {{- with .Values.global.imagePullSecrets }}
      imagePullSecrets:
        {{- toYaml . | nindent 8 }}
      {{- end }}
      restartPolicy: {{ .Values.minio.provisioning.restartPolicy | default "OnFailure" }}
      initContainers:
        - name: wait-for-minio-statefulsets
          image: "{{ include "commonlib.imageSpec" (dict "image" $.Values.global.images.wait_for "global" $.Values.global "registry" $.Values.image.registry) }}"
          imagePullPolicy: "{{ $.Values.global.images.wait_for.pullPolicy }}"
          command: ["wait-for-advanced.sh", "statefulset", "minio", "{{ .Values.minio.provisioning.timeoutSecs | default "180s" }}"]
      containers:
        - name: create-s3-buckets
          image: {{ include "commonlib.imageSpec" (dict "image" .Values.global.images.blob "global" .Values.global "registry" .Values.image.registry) }}
          imagePullPolicy: {{ .Values.global.images.blob.pullPolicy }}
          command:
            - /bin/bash
            - -c
            - |
              {{- range $bucketKey, $bucket := .Values.minio.buckets }}
              {{- if $bucket.purge | default false }}
              blob bucket create {{ tpl $bucket.name $ }} --purge -k $MINIO_ACCESS_KEY -s $MINIO_SECRET_KEY -i
              {{- else }}
              blob bucket create {{ tpl $bucket.name $ }} -k $MINIO_ACCESS_KEY -s $MINIO_SECRET_KEY -i
              {{- end }}
              {{- end }}
          env:
            - name: MINIO_ACCESS_KEY
              valueFrom:
                secretKeyRef:
                  name: {{ .Values.minio.secret }}
                  key: {{ .Values.minio.accessKey }}
            - name: MINIO_SECRET_KEY
              valueFrom:
                secretKeyRef:
                  name: {{ .Values.minio.secret }}
                  key: {{ .Values.minio.secretKey }}
{{- end -}}
{{- end -}}
